@@ -232,7 +232,7 @@ def add_clustering(base_dir):
 
     ## link to the file with all of the sample annotations
     cluster_str+=add_h3("Clustering Results:")
-    cluster_str+=add_file_link("sample_clustering_and_summary/sample_k_means_groups.txt",'sample group annotations')
+    cluster_str+=add_file_link("sample_clustering_and_summary/sample_k_means_groups.tsv",'sample group annotations')
 
     ## get the images from the sample_clustering_and_summary folder
     os.chdir(base_dir+"sample_clustering_and_summary/")
@@ -264,17 +264,17 @@ def add_statistics(base_dir):
     #stats_str+=add_button_head("Statistics")
     stats_str+=add_h3("basic stats")
     stats_str+=add_p("If you find some interesting genes that are different between groups, here are the:")
-    stats_str+=add_file_link("sample_clustering_and_summary/k_group_means.txt",'group means')
+    stats_str+=add_file_link("sample_clustering_and_summary/k_group_means.tsv",'group means')
     stats_str+=add_p('and...')
-    stats_str+=add_file_link("sample_clustering_and_summary/k_group_sd.txt",'group standard deviations')
+    stats_str+=add_file_link("sample_clustering_and_summary/k_group_sd.tsv",'group standard deviations')
     stats_str+=add_p('as well as the')
     # stats_str+=add_file_link("sample_clustering_and_summary/sample_var_enrichment_Zscores.txt",'sample-wise Z-scores')
     # stats_str+=add_p('and...')
-    stats_str+=add_file_link("sample_clustering_and_summary/k_group_enrichment.txt",'group level Z-scores')
+    stats_str+=add_file_link("sample_clustering_and_summary/k_group_enrichment.tsv",'group level Z-scores')
     stats_str+=add_h3("statistical comparisons")
     sig_dir = "sample_clustering_and_summary/significance/"
 
-    stats_str+=add_file_link(sig_dir+'groups_1way_anova_results.txt',"Benjamini-Hoschberg corrected 1-way Anovas")
+    stats_str+=add_file_link(sig_dir+'groups_1way_anova_results.tsv',"Benjamini-Hoschberg corrected 1-way Anovas")
     stats_str+=add_p("For just getting a high-level view of the differences between cell-types, the pathway analysis of these results may be more interesting. Those are a couple tabs down. Looking at the gene expression module usage and the pathways associated with those modules can also be very useful for figuring out the functions of the genes being expressed in a cluster.")
     stats_str+='\n</div>\n'
     stats_str+='\n</div>\n'
@@ -289,7 +289,7 @@ def add_gene_enrichment(base_dir):
     #enrich_str+=add_button_head("Gene enrichment in groups")
     enrich_str+=add_h3("Significantly enriched genes in each group")
     enrich_str+=add_p("Below is a file that contains a table with genes on the left, and groups in columns. If a gene is considered significantly enriched, that means that the BH corrected 1-way Anova was significant, and the gene had a high Z-score in that particular group. If a gene is significantly enriched in that group, the value is True in the corresponding cell in the table, False if it was not significantly enriched.")
-    enrich_str+=add_file_link(sig_dir+"/significant_and_enriched_boolean_table.txt","True/False significantly enriched table")
+    enrich_str+=add_file_link(sig_dir+"/significant_and_enriched_boolean_table.tsv","True/False significantly enriched table")
     enrich_str+=add_p("alternatively, you can use these separated files that simply have the list of significantly enriched genes for each group:")
     enrich_str+=add_button_head('Genes enriched in each group')
     os.chdir(sig_dir)
@@ -323,11 +323,11 @@ def add_gene_enrichment(base_dir):
     if len(enrich_path)>0:
         #enrich_str+=add_h3('Pathway Enrichment for Each Group:')
         enrich_str+=add_button_head('Pathway enrichment for each group')
-        if os.path.isfile(sig_dir+"/combined_neg_log10p_gprofiler.txt"):
+        if os.path.isfile(sig_dir+"/combined_neg_log10p_gprofiler.tsv"):
             enrich_str+=add_p("Below is a combined file with all of the pathways that came out of the analysis of the above genes, enriched in the different groups. We've also created a new algorithm for ranking the importance of these pathways (not to boast, but I'm kind of proud of it). It's based on the information/entropy of the -log10(p-vals). If you look at the -log10(p-vals) at the top of the list, you should find pathways that are really high in some groups and really low in other groups. The overall formula is calculated by taking the sum(KL-divergance)*range(-log10(p-vals)). The KL-divergence is looking for a difference in the distribution between the observed -log10(p-vals) and the distribution expected from an uninformative vector of -log10(p-vals) (this is a Gaussian null hypothesis). Then we multiply the sum(KL-divergance) by the range of -log10(p-vals) to let the most significant pathways with lots of information/low entropy rise to the top.")
-            enrich_str+=add_file_link(sig_dir+"/combined_neg_log10p_gprofiler.txt",'combined pathway analyses')
+            enrich_str+=add_file_link(sig_dir+"/combined_neg_log10p_gprofiler.tsv",'combined pathway analyses')
             enrich_str+=add_p("and here is a file that has a normalized metric that ranks each pathway for their individual importance within each group. It would be useful to sort each of these and see what rises to the top for each 'cell type' or whatever your groups are.")
-            enrich_str+=add_file_link(sig_dir+'/individual_class_importance.txt', 'individual class importance')
+            enrich_str+=add_file_link(sig_dir+'/individual_class_importance.tsv', 'individual class importance')
             enrich_str+=add_p("Below are all of the individual results so that you find which genes were in which pathways in individual groups:")
             enrich_str+=add_button_head("individual pathway files")
         enrich_str+="\t\t\t\t<ul>\n"
@@ -340,7 +340,7 @@ def add_gene_enrichment(base_dir):
             enrich_str+=add_br()
 
 
-        if os.path.isfile(sig_dir+"/combined_neg_log10p_gprofiler.txt"):
+        if os.path.isfile(sig_dir+"/combined_neg_log10p_gprofiler.tsv"):
             enrich_str+="\n\t\t</div>\n"
 
         enrich_str+="\t\t\t\t</ul>\n"
@@ -474,9 +474,9 @@ def add_graph(base_dir):
         graph_str+=add_br()
         graph_str+=add_file_link(os.path.join(base_dir, community_dir, "global_statistics.tsv"),"Here are the stats (BH corrected 1-way anova) for differential module usage among groups.")
         graph_str+=add_br()
-        graph_str+=add_file_link(os.path.join(base_dir, community_dir, "combined_neg_log10p_gprofiler.txt"),"-log10(p-val) for the pathways associated with each module")
+        graph_str+=add_file_link(os.path.join(base_dir, community_dir, "combined_neg_log10p_gprofiler.tsv"),"-log10(p-val) for the pathways associated with each module")
         graph_str+=add_br()
-        individual_class_importance_file = os.path.join(base_dir, community_dir, "individual_class_importance.txt")
+        individual_class_importance_file = os.path.join(base_dir, community_dir, "individual_class_importance.tsv")
         graph_str+=add_file_link(individual_class_importance_file,"The unique pathways of each module (individual class importance).")
         graph_str+=add_br()
         ## second add the folders for each individual community
@@ -591,19 +591,19 @@ def add_autocrine_paracrine(base_dir):
     else:
         #ap_str+=add_button_head("Autocrine/paracrine signaling")
         ap_str+=add_p("Below are the predicted signaling networks")
-        ap_str+=add_file_link(ap_dir+'all_cell_cell_interaction_summary.txt','Number of interactions between all of the groups')
+        ap_str+=add_file_link(ap_dir+'all_cell_cell_interaction_summary.tsv','Number of interactions between all of the groups')
         ap_str+=add_br()
-        ap_str+=add_file_link(ap_dir+'all_cell_type_specific_interactions.txt','A detailed summary of each autocrine/paracrine interaction')
+        ap_str+=add_file_link(ap_dir+'all_cell_type_specific_interactions.tsv','A detailed summary of each autocrine/paracrine interaction')
         ap_str+=add_br()
-        ap_str+=add_file_link(ap_dir+'all_cell_type_specific_interactions_gprofiler.txt','A detailed summary of the pathways signaling across and within groups')
+        ap_str+=add_file_link(ap_dir+'all_cell_type_specific_interactions_gprofiler.tsv','A detailed summary of the pathways signaling across and within groups')
         ap_str+=add_br()
-        ap_str+=add_file_link(ap_dir+'combined_neg_log10p_gprofiler.txt','A table of negative log10 p-values that for each pathway in each interaction. (Zero just means it did not reach signficance)')
+        ap_str+=add_file_link(ap_dir+'combined_neg_log10p_gprofiler.tsv','A table of negative log10 p-values that for each pathway in each interaction. (Zero just means it did not reach signficance)')
         ap_str+=add_br()
-        ap_str+=add_file_link(ap_dir+'individual_class_importance.txt','A table of the individual importance of each pathway for the given group')
+        ap_str+=add_file_link(ap_dir+'individual_class_importance.tsv','A table of the individual importance of each pathway for the given group')
     ap_str += "\n</div>\n"
     return(ap_str)
-        #combined_neg_log10p_gprofiler.txt
-        #individual_class_importance.txt
+        #combined_neg_log10p_gprofiler.tsv
+        #individual_class_importance.tsv
 
 
 def add_gene_annotations(base_dir):
@@ -632,16 +632,15 @@ def add_gene_annotations(base_dir):
     clust_str+=" as well as PyMINEr's custom information theory based prioritization of those pathways."
     anno_str+=add_p(clust_str)
     anno_str+=add_h3("Unique Marker Genes")
-    anno_str+=add_p("")
+    anno_str+=add_p("This tab has some plots and gene annotations for the best marker genes identified that define each cluster from each other.")
     anno_str+=add_h3("Gene Expression Networks")
-    anno_str+=add_p("")
+    anno_str+=add_p("Gene-gene correlation graph-networks are identified; modules of co-expressed genes are identified from these graph networks. Next PyMINEr looks at each cluster & calculates the enrichment of each module in each cluster & performs statistical tests to find differential module usage across clusters. Pathway analysis, and marker gene discovery is also performed for each module to allow the user to easily see the function of the module & how enriched each cluster therefore is for that functional module.")
     anno_str+=add_h3("Autocrine/Paracrine Signaling")
-    anno_str+=add_p("")
+    anno_str+=add_p("Autocrine & Paracrine signaling networks are discovered for the signaling between the clusters, looking at protein-protein interactions across secreted/membrane proteins. Pathway analysis for all cluster-cluster pairs for their signaling interactions is also perofrmed so that the user can at a glance see what the predominant pathways are that signal between two clusters (or within one for autocrine signaling). Alternatively, you can search for a GO:term of interest, & find the specific ligand-receptors that are produced by each cluster-pair that lie within your GO:term pathway of interest.")
     anno_str+='\n</div>\n'
     return(anno_str)
 
 def add_high_marker_genes(base_dir):
-    marker_str = ""
     marker_dir = "sample_clustering_and_summary/significance/high_markers/"
     marker_str = ""
     marker_str += add_tab_header("Unique Marker Genes")
@@ -659,8 +658,11 @@ def add_high_marker_genes(base_dir):
         #marker_str+=add_br()
         marker_str+=add_p("If all three of these criteria are, met you'll find it with an annotated group in the file below. Note that if you have several very closely related groups, there might not be many highly expressed genes that are exclusivly expressed in an individual group. In this case, you might need several markers at once to descriminate them.")
         #marker_str+=add_br()
-        marker_str+=add_file_link(marker_dir+'marker_gene_annotations.tsv',"Highly expressed marker genes")
-        marker_str+=add_img(marker_dir+'genes_of_interest_subset_heatmap.png',"High expression marker genes")
+        marker_str+=add_file_link(marker_dir+'marker_gene_annotations.tsv',"Highly exclusive marker genes")
+        marker_str+=add_img(marker_dir+'genes_of_interest_subset_heatmap.png',"High exclusive marker genes")
+        marker_str+=add_p("In many cases though, a cluster may not as many purely exclusive markers, but rather only have enriched genes that are differentially expressed, but aren't exclusive only to that group. Below we select a hybrid of fairly exclusive, but if there aren't enough exclusive genes, we'll also include some less exclusive ones that are differentially expressed. The below only shows the top n genes for each group (n=5 ususally).")
+        marker_str+=add_file_link(marker_dir+'best_sorted_markers.tsv',"Best marker genes, but not exclusive")
+        marker_str+=add_img(marker_dir+'top_sorted_markers.png',"Best marker genes, but not exclusive")
         marker_str+='\n</div>\n'
     marker_str+='\n</div>\n'
     return(marker_str)
@@ -838,7 +840,4 @@ if __name__ == "__main__":
     args = parser.parse_args()
     ####################
     base_dir = os.path.join(args.base_dir)
-
-
     pyminer_make_website(base_dir)
-#cmd('firefox '+out_file)
